github

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const DefaultCheckName = "Coverage report"

Variables

This section is empty.

Functions

func NewClient

func NewClient(ctx context.Context, token string) *github.Client

Types

type CheckCreator

type CheckCreator interface {
	CreateCheckRun(ctx context.Context, owner, repo string, opts github.CreateCheckRunOptions) (*github.CheckRun, *github.Response, error)
}

CheckCreator is just an interface to allow easy testing

type CheckRun added in v0.0.4

type CheckRun struct {
	// contains filtered or unexported fields
}

CheckRun implements coverage report notification for github check runs.

func NewCheckRun added in v0.0.4

func NewCheckRun(cc CheckCreator, owner, repo, headSHA, checkName string) *CheckRun

func (*CheckRun) Notify added in v0.0.4

func (c *CheckRun) Notify(ctx context.Context, body string) error

Notify creates a check run into github pull request with the given coverage report.

type StepSummary added in v0.0.4

type StepSummary struct{}

StepSummary implements coverage report notification for github actions step summary.

func NewStepSummary added in v0.0.4

func NewStepSummary() *StepSummary

func (*StepSummary) Notify added in v0.0.4

func (*StepSummary) Notify(_ context.Context, body string) error

Notify creates a check run into github pull request with the given coverage report.

Jump to