Documentation
¶
Index ¶
Constants ¶
const DefaultCheckName = "Coverage report"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CheckCreator ¶
type CheckCreator interface {
CreateCheckRun(ctx context.Context, owner, repo string, opts github.CreateCheckRunOptions) (*github.CheckRun, *github.Response, error)
}
CheckCreator is just an interface to allow easy testing
type CheckRun ¶ added in v0.0.4
type CheckRun struct {
// contains filtered or unexported fields
}
CheckRun implements coverage report notification for github check runs.
func NewCheckRun ¶ added in v0.0.4
func NewCheckRun(cc CheckCreator, owner, repo, headSHA, checkName string) *CheckRun
type StepSummary ¶ added in v0.0.4
type StepSummary struct{}
StepSummary implements coverage report notification for github actions step summary.
func NewStepSummary ¶ added in v0.0.4
func NewStepSummary() *StepSummary
Click to show internal directories.
Click to hide internal directories.